Class: ErpIntegration::Configuration
- Inherits:
-
Object
- Object
- ErpIntegration::Configuration
- Defined in:
- lib/erp_integration/configuration.rb
Overview
Use the ‘Configuration` class to configure the ERP Integration gem. Use an initializer in your project configure the ERP Integration gem.
Instance Attribute Summary collapse
-
#api_key_rotation_threshold ⇒ Object
The ‘api_key_rotation_threshold` is used by the `ApiKeysRotation` middleware it will rotate the API key when the remaining requests are less than the threshold.
- #bill_of_material_adapter ⇒ Object
- #bill_of_material_input_adapter ⇒ Object
- #bill_of_material_output_adapter ⇒ Object
- #channel_listing_adapter ⇒ Object
- #country_adapter ⇒ Object
- #customer_shipment_adapter ⇒ Object
- #customer_shipment_return_adapter ⇒ Object
-
#fulfil_api_keys ⇒ Array<String>
The ‘fulfil_api_keys` sets a single or a list of API keys to use in the `FulfilClient` to authorize the requests to the Fulfil API endpoints.
-
#fulfil_base_url ⇒ String
The ‘fulfil_base_url` is used by the `FulfilClient` to connect to the right Fulfil API endpoints.
- #gift_card_adapter ⇒ Object
- #internal_shipment_adapter ⇒ Object
- #location_adapter ⇒ Object
- #party_address_adapter ⇒ Object
- #product_adapter ⇒ Object
- #product_category_adapter ⇒ Object
- #product_option_adapter ⇒ Object
- #product_option_set_adapter ⇒ Object
- #product_template_adapter ⇒ Object
- #production_order_adapter ⇒ Object
- #purchase_order_adapter ⇒ Object
- #purchase_order_line_adapter ⇒ Object
- #purchase_product_supplier_adapter ⇒ Object
- #purchase_request_adapter ⇒ Object
- #sales_line_option_adapter ⇒ Object
- #sales_order_adapter ⇒ Object
- #sales_order_line_adapter ⇒ Object
- #sales_return_reason_adapter ⇒ Object
- #stock_bin_transfer_adapter ⇒ Object
- #stock_move_adapter ⇒ Object
- #supplier_shipment_adapter ⇒ Object
- #task_adapter ⇒ Object
- #tracking_number_adapter ⇒ Object
Instance Method Summary collapse
- #box_type_adapter ⇒ Object
- #carrier_adapter ⇒ Object
- #carrier_service_adapter ⇒ Object
-
#initialize(**options) ⇒ Configuration
constructor
A new instance of Configuration.
- #inventory_by_location_report_adapter ⇒ Object
- #logger ⇒ Object
- #logger=(logger) ⇒ Object
-
#rate_limiters ⇒ Object
Rate limiters that will be used for HTTP operations on Client to manage the number of requests made to avoid rate limiting by the API provider.
-
#rate_limiters=(rate_limiters) ⇒ Object
Sets the rate limiters that will be used.
- #webhook_adapter ⇒ Object
Constructor Details
#initialize(**options) ⇒ Configuration
Returns a new instance of Configuration.
181 182 183 184 185 |
# File 'lib/erp_integration/configuration.rb', line 181 def initialize(**) .each_pair do |key, value| public_send("#{key}=", value) if respond_to?("#{key}=") end end |
Instance Attribute Details
#api_key_rotation_threshold ⇒ Object
The ‘api_key_rotation_threshold` is used by the `ApiKeysRotation` middleware it will rotate the API key when the remaining requests are less than the threshold.
Set the ‘api_key_rotation_threshold` to 0, it you don’t want to rotate by the remaining requests.
29 30 31 |
# File 'lib/erp_integration/configuration.rb', line 29 def api_key_rotation_threshold @api_key_rotation_threshold end |
#bill_of_material_adapter ⇒ Object
191 192 193 |
# File 'lib/erp_integration/configuration.rb', line 191 def bill_of_material_adapter @bill_of_material_adapter || :fulfil end |
#bill_of_material_input_adapter ⇒ Object
195 196 197 |
# File 'lib/erp_integration/configuration.rb', line 195 def bill_of_material_input_adapter @bill_of_material_input_adapter || :fulfil end |
#bill_of_material_output_adapter ⇒ Object
199 200 201 |
# File 'lib/erp_integration/configuration.rb', line 199 def bill_of_material_output_adapter @bill_of_material_output_adapter || :fulfil end |
#channel_listing_adapter ⇒ Object
215 216 217 |
# File 'lib/erp_integration/configuration.rb', line 215 def channel_listing_adapter @channel_listing_adapter || :fulfil end |
#country_adapter ⇒ Object
219 220 221 |
# File 'lib/erp_integration/configuration.rb', line 219 def country_adapter @country_adapter || :fulfil end |
#customer_shipment_adapter ⇒ Object
223 224 225 |
# File 'lib/erp_integration/configuration.rb', line 223 def customer_shipment_adapter @customer_shipment_adapter || :fulfil end |
#customer_shipment_return_adapter ⇒ Object
227 228 229 |
# File 'lib/erp_integration/configuration.rb', line 227 def customer_shipment_return_adapter @customer_shipment_return_adapter || :fulfil end |
#fulfil_api_keys ⇒ Array<String>
The ‘fulfil_api_keys` sets a single or a list of API keys to use in the `FulfilClient` to authorize the requests to the Fulfil API endpoints.
18 19 20 |
# File 'lib/erp_integration/configuration.rb', line 18 def fulfil_api_keys @fulfil_api_keys end |
#fulfil_base_url ⇒ String
The ‘fulfil_base_url` is used by the `FulfilClient` to connect to the right Fulfil API endpoints.
23 24 25 |
# File 'lib/erp_integration/configuration.rb', line 23 def fulfil_base_url @fulfil_base_url end |
#gift_card_adapter ⇒ Object
231 232 233 |
# File 'lib/erp_integration/configuration.rb', line 231 def gift_card_adapter @gift_card_adapter || :fulfil end |
#internal_shipment_adapter ⇒ Object
235 236 237 |
# File 'lib/erp_integration/configuration.rb', line 235 def internal_shipment_adapter @internal_shipment_adapter || :fulfil end |
#location_adapter ⇒ Object
243 244 245 |
# File 'lib/erp_integration/configuration.rb', line 243 def location_adapter @location_adapter || :fulfil end |
#party_address_adapter ⇒ Object
255 256 257 |
# File 'lib/erp_integration/configuration.rb', line 255 def party_address_adapter @party_address_adapter || :fulfil end |
#product_adapter ⇒ Object
259 260 261 |
# File 'lib/erp_integration/configuration.rb', line 259 def product_adapter @product_adapter || :fulfil end |
#product_category_adapter ⇒ Object
263 264 265 |
# File 'lib/erp_integration/configuration.rb', line 263 def product_category_adapter @product_category_adapter || :fulfil end |
#product_option_adapter ⇒ Object
267 268 269 |
# File 'lib/erp_integration/configuration.rb', line 267 def product_option_adapter @product_option_adapter || :fulfil end |
#product_option_set_adapter ⇒ Object
271 272 273 |
# File 'lib/erp_integration/configuration.rb', line 271 def product_option_set_adapter @product_option_set_adapter || :fulfil end |
#product_template_adapter ⇒ Object
275 276 277 |
# File 'lib/erp_integration/configuration.rb', line 275 def product_template_adapter @product_template_adapter || :fulfil end |
#production_order_adapter ⇒ Object
279 280 281 |
# File 'lib/erp_integration/configuration.rb', line 279 def production_order_adapter @production_order_adapter || :fulfil end |
#purchase_order_adapter ⇒ Object
283 284 285 |
# File 'lib/erp_integration/configuration.rb', line 283 def purchase_order_adapter @purchase_order_adapter || :fulfil end |
#purchase_order_line_adapter ⇒ Object
287 288 289 |
# File 'lib/erp_integration/configuration.rb', line 287 def purchase_order_line_adapter @purchase_order_line_adapter || :fulfil end |
#purchase_product_supplier_adapter ⇒ Object
291 292 293 |
# File 'lib/erp_integration/configuration.rb', line 291 def purchase_product_supplier_adapter @purchase_product_supplier_adapter || :fulfil end |
#purchase_request_adapter ⇒ Object
295 296 297 |
# File 'lib/erp_integration/configuration.rb', line 295 def purchase_request_adapter @purchase_request_adapter || :fulfil end |
#sales_line_option_adapter ⇒ Object
311 312 313 |
# File 'lib/erp_integration/configuration.rb', line 311 def sales_line_option_adapter @sales_line_option_adapter || :fulfil end |
#sales_order_adapter ⇒ Object
315 316 317 |
# File 'lib/erp_integration/configuration.rb', line 315 def sales_order_adapter @sales_order_adapter || :fulfil end |
#sales_order_line_adapter ⇒ Object
319 320 321 |
# File 'lib/erp_integration/configuration.rb', line 319 def sales_order_line_adapter @sales_order_line_adapter || :fulfil end |
#sales_return_reason_adapter ⇒ Object
323 324 325 |
# File 'lib/erp_integration/configuration.rb', line 323 def sales_return_reason_adapter @sales_return_reason_adapter || :fulfil end |
#stock_bin_transfer_adapter ⇒ Object
327 328 329 |
# File 'lib/erp_integration/configuration.rb', line 327 def stock_bin_transfer_adapter @stock_bin_transfer_adapter || :fulfil end |
#stock_move_adapter ⇒ Object
331 332 333 |
# File 'lib/erp_integration/configuration.rb', line 331 def stock_move_adapter @stock_move_adapter || :fulfil end |
#supplier_shipment_adapter ⇒ Object
335 336 337 |
# File 'lib/erp_integration/configuration.rb', line 335 def supplier_shipment_adapter @supplier_shipment_adapter || :fulfil end |
#task_adapter ⇒ Object
339 340 341 |
# File 'lib/erp_integration/configuration.rb', line 339 def task_adapter @task_adapter || :fulfil end |
#tracking_number_adapter ⇒ Object
343 344 345 |
# File 'lib/erp_integration/configuration.rb', line 343 def tracking_number_adapter @tracking_number_adapter || :fulfil end |
Instance Method Details
#box_type_adapter ⇒ Object
203 204 205 |
# File 'lib/erp_integration/configuration.rb', line 203 def box_type_adapter @box_type_adapter || :fulfil end |
#carrier_adapter ⇒ Object
207 208 209 |
# File 'lib/erp_integration/configuration.rb', line 207 def carrier_adapter @carrier_adapter || :fulfil end |
#carrier_service_adapter ⇒ Object
211 212 213 |
# File 'lib/erp_integration/configuration.rb', line 211 def carrier_service_adapter @carrier_service_adapter || :fulfil end |
#inventory_by_location_report_adapter ⇒ Object
239 240 241 |
# File 'lib/erp_integration/configuration.rb', line 239 def inventory_by_location_report_adapter @inventory_by_location_report_adapter || :fulfil end |
#logger ⇒ Object
247 248 249 |
# File 'lib/erp_integration/configuration.rb', line 247 def logger @logger || Logger.new(nil) end |
#logger=(logger) ⇒ Object
251 252 253 |
# File 'lib/erp_integration/configuration.rb', line 251 def logger=(logger) @logger = Logger.new(logger) end |
#rate_limiters ⇒ Object
Rate limiters that will be used for HTTP operations on Client to manage the number of requests made to avoid rate limiting by the API provider.
301 302 303 |
# File 'lib/erp_integration/configuration.rb', line 301 def rate_limiters @rate_limiters ||= [] end |
#rate_limiters=(rate_limiters) ⇒ Object
Sets the rate limiters that will be used
307 308 309 |
# File 'lib/erp_integration/configuration.rb', line 307 def rate_limiters=(rate_limiters) @rate_limiters = (rate_limiters || []).each { |limiter| RateLimiter.validate!(limiter) } end |
#webhook_adapter ⇒ Object
347 348 349 |
# File 'lib/erp_integration/configuration.rb', line 347 def webhook_adapter @webhook_adapter || :fulfil end |